@@ -2,7 +2,7 @@
     
     lv2types.hpp - support file for writing LV2 plugins in C++
     
-    Copyright (C) 2006-2008 Lars Luthman <lars.luthman@gmail.com>
+    Copyright (C) 2006-2008 Lars Luthman <mail@larsluthman.net>
 
     The first version of the URIMap class was written by Dave Robillard.
     It has since been modified.
@@ -181,16 +181,19 @@ namespace LV2 {
       }
       
     protected:
-      
       /** This returns a numeric identifier for a given URI and map.
-	  This is used for e.g. getting numeric IDs for event types
-	  specified by URIs. A return value of 0 should be considered to 
-	  mean that the URI you passed is not supported by the host.
+          This is used for e.g. getting numeric IDs for event types
+          specified by URIs. A return value of 0 should be considered to
+          mean that the URI you passed is not supported by the host.
+
+          This function can be used even if the host does not support
+          the URI map extension, and will then always return 0 for any URI.
+
 	  @param map An URI to be used as namespace.
 	  @param uri The URI that you want to map to a numeric ID.
       */
       uint32_t uri_to_id(const char* map, const char* uri) const {
-	return m_func(m_callback_data, map, uri);
+        return m_func ? m_func(m_callback_data, map, uri) : 0;
       }
     
       LV2_URI_Map_Callback_Data m_callback_data;
