@@ -582,14 +582,16 @@ namespace PAQ {
 
 
   RDFTerm* TurtleParser::do_datatypeString(iter_t iter) {
+    assert(iter->children.size() == 3);
     iter_t child = iter->children.begin();
-    RDFTerm* data = 0;
-    RDFTerm* type = 0;
-    if (child->value.id() == parser_id(&quotedString))
-      data = do_quotedString(child);
-    else if (child->value.id() == parser_id(&resource))
-      type = do_resource(child);
+    assert(child->value.id() == parser_id(&quotedString));
+    RDFTerm* data = do_quotedString(child);
     assert(data);
+    // Skip two nodes ahead. We don't care about the "^^" string, and
+    // we know that there are exactly 3 children.
+    std::advance(child, 2);
+    assert(child->value.id() == parser_id(&resource));
+    RDFTerm* type = do_resource(child);
     assert(type);
     data->datatype = type;
     return data;
